## Bewertung
1. Identifying Spatio-Temporal Drivers of Extreme Events
2. The Elephant in the Room: Towards A Reliable Time-Series Anomaly Detection Benchmark
3. Estimating the Hallucination Rate of Generative AI
4. Understanding Transformers via N-Gram Statistics
5. Off to new Shores: A Dataset & Benchmark for (near-)coastal Flood Inundation Forecasting
6. CycleNet: Enhancing Time Series Forecasting through Modeling Periodic Patterns

*Nicht umsetzbar:*
+ DRACO: A Denoising-Reconstruction Autoencoder for Cryo-EM
+ PEACE: A Dataset of Pharmaceutical Care for Cancer Pain Analgesia Evaluation and Medication Decision
+ Why Transformers Need Adam: A Hessian Perspective

## [Identifying Spatio-Temporal Drivers of Extreme Events](https://neurips.cc/virtual/2024/poster/96083)
+ **Hintergrund:** Verständnis der globalen Klimaveränderungen
+ **Datensatz:**
	+ Klimadaten mit physikalischen Messwerten
+ **Problemstellung:** 
	+ Zeitverzögerung zw. Extremereignissen und Auslöser mit inhomogener räumlicher Ausdehnung
	+ Fokus auf Dürren in der Landwirtschaft
+ **Ansatz:** 
	+ Training end-to-end
	+ Vorhersage der räumlich-zeitlichen Extremereignissen und Vorhersage der räumlich-zeitlichen Auslöser anhand physikalischer Eingabedaten
+ **Umsetzung:**
	+ Das Netzwerk quantisiert die raum-zeitlichen Eingabevariablen in binäre Zustände
	+ Netzwerk wird dann gezwungen Extremereignisse aus räumlich-zeitlichen Binärmasken identifizierter Treiber vorherzusagen für jede Zeitreihe von Eingabedaten
	+ Dadurch identifiziert das Netzwerk erfolgreich Treiber, die mit Extremen korreliert sind
+ **Model-Architektur:** Besteht aus 3 Komponenten
	1. Extraktion wichtiger Features durch einen Merkmalsextraktor aus jeder Eingabevariablen
	2. Quantisierungsschicht: nimmt extrahierte Merkmale (als Eingabe) und klassifiziert diese in Auslöser (drivers) --> Transformiert Daten in eine binäre Repräsentation
	3. Klassifikator: Nutzt als Eingabe die Variablen, Ort und Zeit, wo die Auslöser erkannt wurden und sagt die extremen Dürren vorher
+ **Bemerkungen:**
	+ Gute Erklärungen (ausführlich) zur Umsetzung und mathematischen Formeln
	+ Code und Datensatz öffentlich zugänglich

## [Off to new Shores: A Dataset & Benchmark for (near-)coastal Flood Inundation Forecasting](https://neurips.cc/virtual/2024/poster/97766)
+ **Hintergund:** Vorhersage von Flutkatastrophen an Küstenregionen
+ **Datensatz:**
	+ Eigener, neuer erstellt
+ **Bemerkung:**
	+ Wenig Erklärungen zur genauen Umsetzung, Generierung des Datensatzes und mathematichen Hintergrund
	+ Datensatz und Code verfügbar : [Git Repo](https://github.com/Multihuntr/GFF)
	+ Im Git gute Erklärungen

## [The Elephant in the Room: Towards A Reliable Time-Series Anomaly Detection Benchmark](https://neurips.cc/virtual/2024/poster/97690)
+ **Hintergrund:** Anomalie-Erkennung in Zeitseriendaten 
+ **Model:** VUS-PR
+ **Problemstellung:**
	+ fehlerhafte Datensätze
	+ Bewertungen haben einen Bias
	+ Inkonsistentes Benchmarking
+ **Datensatz:**
	+ Hoch-qualitative Zeitserien aus sehr diversen Datensatzsammlung
	+ Sammlung von 40 Datensätzen
+ **Umsetzung:**
	+ Implementierung von 40 statistischen Algorithmen zur Detektion der Anomalien
	+ Mit Hyperparameter-Tuning
	+ Einheitliches Setup für einen reproduzierbaren und fairen Vergleich
	+ Binäre Klassifizierung der Datenpunkte: *Normal* und *Abnormal*
+ **Ergebnisse:**
	+ Stellen  gängige Meinung über die Überlegenheit fortschrittlicher neuronaler Netzwerkarchitekturen in Frage
	+ Zeigen, dass einfachere Architekturen und statistische Methoden oft eine bessere Leistung erbringen
+ **Bemerkungen:**
	+ Ausführliche Erklärungen, sowie Datensätze und implementierte Algorithmen im Git
	+ Paper erklärt auch viel zum Hintergrund
	+ Komplette Implementierung eventuell zu Umfangreich, aber Vergleich mit eigenem Neuronalem Netz möglich

## [CycleNet: Enhancing Time Series Forecasting through Modeling Periodic Patterns](https://neurips.cc/virtual/2024/poster/94391)
+ **Hintergrund:** Erforschung der explizieten Modellierung von Periodizität in Lang-Zeit-Seriendaten zur Verbesserung von LSTF-Modellen (Vorhersagen in diesen Daten)
+ **Modell:** CycleNet
+ **Bereiche:** Elektrizität, Wetter und Energie
+ **Umsetzung:**
	+ Residual Cycle Forecasting (RCF): Nutzt lernbare rekurrente Zyklen zur Modellierung  periodischer Muster zur Vorhersage auf den modellierten Zyklen
	+ RCF wird kombiniert mit einer linearen Schicht oder einem seichten MLP
+ **Bemerkung:**
	+ Gute Erklärungen im Git, im Paper zur Modelarchitektur auch
	+ Wenig Informationen zum Datensatz, scheint von Torch geladen zu werden
	+ Viele Mathematischen Erklärungen im Paper

## [DRACO: A Denoising-Reconstruction Autoencoder for Cryo-EM](https://neurips.cc/virtual/2024/poster/93299)
+ **Hintergund:** Modelle übersehen die schwere Korruption in der kryogenen Elektronenmikroskopie
+ **Model:** DRACO
+ **Datensatz:**
	+ Erstelle aus einem öffentlichem Datensatz, der Filme oder Mikrografien enthält
+ **Umsetzung:**
	+ cryo-EM-Videos werden als einzelne Bilder umgewandelt und diese als unabhängige verrauschte Bilder betrachtet
	+ Verwendung eines Autoencoders
+ **Bemerkung:**
	+ Code und Datensatz nicht öffentlich zugänglich

## [PEACE: A Dataset of Pharmaceutical Care for Cancer Pain Analgesia Evaluation and Medication Decision](https://neurips.cc/virtual/2024/poster/97596)
+ **Hintergrund:** Unterstützung bei dem Langzeit-Schmerzmanagement bei Krebspatienten durch personalisierte Medikamentenpläne
+ **Datensatz:**
	+ Enthält Daten zu über 38.000 Patienten
	+ Daten: Demografie, Klinische Untersuchung, Behandlungsergebnisse, Medikamentenpläne und Selbsteinschätzung der Patienten
+ **Umsetzung:**
	+ Erstellung eines eigenen Datzensatzes und Vergleich verschiedener Modelle zur Genauigkeit und Repräsentationsfähigkeit / Aussagekraft des Datensatzes
+ **Bemerkung:**
	+ Datensatz öffentlich zugänglich
	+ Keine eigene Implementierung eines Modells, lediglich ein Datensatz, der für seine Aussagekraft untersucht wurde

## [Understanding Transformers via N-Gram Statistics](https://neurips.cc/virtual/2024/poster/94849)
+ **Hintergrund:** Verständnis darüber, wie die Vorhersage von Transformern von Kontext-Bedingungen abhängt
+ **Datensatz:**
	+ TinyStories: Datensatz mit Kindergeschichten, die aus synthetischen Eingaben an GPT-4 generiert wurden
+ **Umsetzung:**
	+ Mit Datensatz wurde ein Standart- Decoder-only Transformer trainiert
	+ Nutzung von N-Gramm basierten Statistiken der Trainingsdaten
	+ Erstellen von N-Gramm-Regeln zur Approximierung der Vorhersage des Transformers
+ **Bemerkung:**
	+ Datensatz: TinyStories
	+ Code nicht öffentlich zugänglich
	+ Regeln wurden erklärt, weitere Einarbeitung notwendig, um diese zu verstehen


## [Estimating the Hallucination Rate of Generative AI](https://nips.cc/virtual/2024/poster/95553)
+ **Hintergrund:** Schätzung der Halluzinationsrate von ICL (in-context-learning) mit generativer KI
	+ Halluzination: Als generierte Antwort mit geringer Model-Likelihood eines gegebenes Mechanismus
	+ Annahme, dass Vorhersage auf einen Posterior eines bayschen Modells basiert
+ **Umsetzung:** 
	+ Bewertung der Log-Wahrscheinlichkeit von Antworten und generierten Vorhersage-Fragen
+ **Bemerkung:**
	+ Pseudo-Code und viele mathematische Formeln vorhanden
	+ Code und Datensatz öffentlich zugänglich

## [Why Transformers Need Adam: A Hessian Perspective](https://neurips.cc/virtual/2024/poster/94790)
+ Reine theoretische Analyse, keine Implementierung