[Anonmalidetektion](https://github.com/TheDatumOrg/TSB-UAD/blob/main/docs/evaluation/VUS.md)
**Welche Anomalien werden betrachtet?**
![](../bilder/types_of_anomalies.png)

**Wie erfolgt eine Anomaliedetektion?**
![](../bilder/pipeline.png)
# Runtime
+ on single CPU process
![](../bilder/runtime.png)

# Detection Pipeline
The typical pipeline for time series anomaly detection involves three key stages: (i) preprocessing of time series data, (ii) application of anomaly detection algorithms, and (iii) post-processing of the resulting anomaly scores.
## [The Elephant in the Room: Towards A Reliable Time-Series Anomaly Detection Benchmark](https://neurips.cc/virtual/2024/poster/97690)
+ **Hintergrund:** Anomalie-Erkennung in Zeitseriendaten 
+ **Model:** TSB-AD
+ **Evaluations-Modell:** VUS-PR
+ **Probleme:**
	+ fehlerhafte Datensätze, fehlerhaftes oder inkonsistentes Labeling
	+ Bewertungen haben einen Bias,  weil Anomalien oft erst am Ende einer Zeitserie auftreten
	+ Klasseninbalance erschwert Klassifikation der Daten, wohingegen ein zu hohen Auftreten an Anomalien unrealistisch ist und der Zuordnung als Anomalie widerspricht
	
![](../../bilder/dataset_issues.png)
+ **Datensatz:**
	+ 1070 Hoch-qualitative Zeitserien aus sehr diversen Datensatzsammlung
	+ Sammlung von  > 40 Datensätzen
	+ 13 univariate und 20 multivariat Datensätze zur Anomalie-Erkennung
	+ multivariate Zeitreihen wurden in univariate Formate umgewandelt, indem jeder Kanal als eigenständige Zeitreihe betrachtet wird
		+ bei den multivariaten enthalten nicht alle Kanäle Informationen, die für die Anomalieerkennung relevant sind und andere haben kategorische, binäre oder zufällige Daten enthalten
		+ Korrelationsanalyse, um herauszufinden, welche Kanäle mit den Anomalien korrelieren und damit wichtige Merkmale sind
		+ Anhand der Evaluationsbewertungen wurden die Top 40% der Zeitserien genommen, für einen hochqualitativen Datensatz
	+ **Erstellen:**
		1. Datensammlung und Evaluation geeigneter Kanäle, Vergrößerung der univariaten Datensätze anhand wichtiger Kanäle der multivariaten Daten
		2. Bewertung der Label
		3. Nutzen von Algorithmen zur Erkennung von Anomalien zur Unterstützung der Überprüfung der Labelqualität und Teilung der univariaten (TSB-AD-U) und multivariaten (TSB-AD-M) in in Test- und Trainingsdatensatz
+ **Umsetzung:**
	+ Implementierung von 40 statistischen Algorithmen zur Detektion der Anomalien
	+ Mit Hyperparameter-Tuning
	+ Einheitliches Setup für einen reproduzierbaren und fairen Vergleich
	+ Binäre Klassifizierung der Datenpunkte: *Normal* und *Abnormal*
	+ Klassifikationsmethoden:
		+ **Statistische Algorithmen:** statistische Methoden zur Anomalieerkennung
		+ **Neuronale Netze:** oft semi-supervised
		+ **Foundation-basierte Modelle:**
+ **Evaluation**metriken:
	+ VUS-PR (Volume Under Surface of Precision-Recall) ist die zuverlässigste und genaueste Metrik für die Anomalie-erkennung in Zeitreihen
	+ **Punktuelle Maße:**
		+ AUC-ROC
		+ AUC-PR
		+ Standard-F1
		+ PA-F1: wendet die Punktanpassung auf die Vorhersage an
		+ Event-based-F1: Beseitigt Verzerrungen durch Punktanpassungstechniken, indem jedes Anomaliesegment als einzelnes Ereignis behandelt wird und nur einmal entweder zu einem richtig positiven oder einem falsch negativen Ergebnis beiträgt
	+ **Abstandsmaße**: robustere Bewertung der Modelle
		+ R-based-F1: betrachtet zusätzlich traditionelle Messgrößen durch die Einbeziehung von Faktoren wie Existenzbelohnung, Überlappungsbelohnung und Kardinalitätsfaktor
		+ Affiliation-F1: konzentriert sich auf die Nähe zwischen vorhergesagten und tatsächlichen Anomaliesequenzen und misst den zeitlichen Abstand zwischen ihrem Auftreten 
		+ Volume Under the Surface (VUS) Messungen, VUS-ROC und VUS-PR: integrieren einen Toleranzpuffer um die Outlier-Grenzen und übernehmen kontinuierliche Werte über binäre Label
		+ PATE: wendet eine näherungsbasierte Gewichtung um Anomalieintervalle an, um die gewichtete Version des Bereichs unter der Genauigkeits- und Abrufkurve zu berechnen
	
+ **Ergebnisse:**
	+ Stellen  gängige Meinung über die Überlegenheit fortschrittlicher neuronaler Netzwerkarchitekturen in Frage
	+ Zeigen, dass einfachere Architekturen und statistische Methoden oft eine bessere Leistung erbringen  als komplexe neuronale Netzwerke
	+ Allerdings könnten neuronale Netze gute Ergebnisse bei multivariaten Zeitreihen liefern
	+ VUS-PR zeigte im Vergleich zu anderen Maßnahmen erhebliche Robustheit gegenüber Verzögerungen
	+ Die Top 12 Methoden bestehen überwiegend aus statistischen Ansätzen
	+ In TSB-AD-M zeigen neuronale Netzwerkmethoden wie CNN und OmniAnomaly bessere Ergebnisse, aber auch statistische Methoden bleiben in multivariaten Fällen sehr effektiv
	+ Foundation-Model-basierte Ansätze starke Leistung bei der Erkennung von Punktanomalien zeigen
	+ Foundation-model-based approaches demonstrate strong potential in detecting point-based anomalies, with TimesFM and Chronos ranking first and third, respectively. However, for sequence-based anomalies, statistical methods continue to dominate, with Sub-KNN and POLY outperforming other methods. Overall, neural networks appear more effective in detecting point anomalies.
	+ No neural-network-based approach ranks as a top candidate in single-anomaly scenarios; however, in more complex cases with multiple anomalies, MOMENT begins to show effectiveness
	+ Statistical-based methods generally demonstrate robust performance, while neural network-based methods do not exhibit the superiority often attributed to them.
	+ Simpler architectures such as CNNs and LSTMs generally outperform more complex designs, such as advanced transformer architectures.
	+ Foundation models excel at detecting point-based anomalies but struggle with sequence anomalies mostly due to their predictive mechanism, which estimates only one new value per step using a limited look-back window. When faced with long sequence anomalies, the constrained temporal context often leads to reduced performance and noisy scores
+ **Einfluss von IoT-Technologien**
	+  hat die Menge an sequentiellen Messungen drastisch erhöht
	+ wesentliche Grundlage für viele Aufgaben in der Analyse
	+ Zentrale Aufgaben u.a. Zeitreihenanalyse
+ **Bemerkungen:**
	+ Ausführliche Erklärungen, sowie Datensätze und implementierte Algorithmen im Git
	+ Paper erklärt auch viel zum Hintergrund
	+ Komplette Implementierung eventuell zu Umfangreich, aber Vergleich mit eigenem Neuronalem Netz möglich
+ **Allgemeine Probleme**
	- Missling Labels bzw.  Inkonsistente Labelings
	- Bias im Datensatz (Anomalien treten überwiegend gegen Ende einer Zeitreihe auf)
	- Ungleichgewichten im Datensatz zw. Normalen und Abnormalen Datenpunkten
+ **Algorithmen:**
	+ Statistische Methoden: Fokus auf klassische Ansätze, die auf mathematischen Modellen basieren, um Anomalien durch Abweichungen von erwarteten Mustern zu identifizieren.
	+ Neuronale Netzwerk-basierte Methoden: Diese Methoden lernen typische Muster in historischen Trainingsdaten, die keine Anomalien enthalten. Abweichungen in neuen Testdaten werden als potenzielle Anomalien erkannt.
	+ Foundation-Model-basierte Methoden: Diese Modelle zeichnen sich durch beeindruckende Few- Shot- und Zero-Shot-Fähigkeiten aus. Hier kann man LLMs adaptieren wie z.b OFA Modell oder MOMENT (Modell für Zeitreihen) 
