[Erklärungen vom Paper](https://github.com/TheDatumOrg/TSB-UAD/tree/main/docs/algorithms)
[Einteilung](https://github.com/TheDatumOrg/TSB-UAD/blob/main/docs/overview/References.md)

![](../bilder/types_of_methods.png)
**Distanzbasierte Methoden:**
*Proximity-based (Nähebasiert)*:
+ 
## Statistische Algorithmen
1. (Sub)-MCD
   +  is based on minimum covariance determinant, which seeks to find a subset of all the sequences to estimate the mean and covariance matrix of the subset with minimal determinant. Subsequently, Mahalanobis distance is utilized to calculate the distance from sub-sequences to the mean, which is regarded as the anomaly score.|
2. (Sub)-OCSVM
   + fits the dataset to find the normal data's boundary by maximizing the margin between the origin and the normal samples
   + varies from the SVM generic version in that the resulting problem of quadratic optimization includes an allowance for a specific small predefined outliers percentage
   + outliers lie between the origin and the optimal separating hyper plane. All the remaining data fall on the opposite side of the optimal separating hyper plane, belonging to a single nominal class
   + outputs a score that represents the distance from the data point being tested to the optimal hyper plane. Positive values for the one-class SVM output represent normal behavior (with higher values representing greater normality) and negative values represent abnormal behavior
   + (SALIMA, Omar; ASRI, Ngadi; HAMID, H. Jebur. Machine learning techniques for anomaly detection: an overview. 2013.)
1. (Sub)-LOF
   + calculates the anomaly score by comparing local density with that of its neighbors.
   + depends on how the instance is isolated to the surrounding neighborhood
2. (Sub)-KNN
   + produces the anomaly score of the input instance as the distance to its k -th nearest neighbor.
3. KMeansAD
   + calculates the anomaly scores for each sub-sequence by measuring the distance to the centroid of its assigned cluster, as determined by the k-means algorithm.
4. CBLOF
   + is clluster-based LOF, which calculates the anomaly score by first assigning samples to clusters, and then using the distance among clusters as anomaly scores.
5. POLY
   + detect pointwise anomolies using polynomial approximation. A GARCH method is run on the difference between the approximation and the true value of the dataset to estimate the volatility of each point.
6. (Sub)-IForest
   + constructs the binary tree, wherein the path length from the root to a node serves as an indicator of anomaly likelihood; shorter paths suggest higher anomaly probability.
7. (Sub)-HBOS
   + constructs a histogram for the data and uses the inverse of the height of the bin as the anomaly score of the data point.
8. KShapeAD
    + identifies the normal pattern based on the k-Shape clustering algorithm and computes anomaly scores based on the distance between each sub-sequence and the normal pattern. KShapeAD improves KMeansAD as it relies on a more robust time-series clustering method and corresponds to an offline version of the streaming SAND method.
9. MatrixProfile
    + identifies anomalies by pinpointing the subsequence exhibiting the most substantial nearest neighbor distance.
10. (Sub)-PCA
    + projects data to a lower-dimensional hyperplane, with significant deviation from this plane indicating potential outliers.
11. RobustPCA
    + is built upon PCA and identifies anomalies by recovering the principal matrix.
12. EIF
    + is an extension of the traditional Isolation Forest algorithm, which removes the branching bias using hyperplanes with random slopes.
13. SR
    + begins by computing the *Fourier Transform* of the data, followed by the *spectral residual of the log amplitude*. The Inverse Fourier Transform then maps the sequence back to the time domain, creating a saliency map. The anomaly score is calculated as the relative difference between saliency map values and their moving averages.
14. COPOD
    + is a copula-based parameter-free detection algorithm, which first constructs an empirical copula, and then uses it to predict tail probabilities of each given data point to determine its level of extremeness.
15. Series2Graph
    + converts the time series into a directed graph representing the evolution of subsequences in time. The anomalies are detected using the weight and the degree of the nodes and edges respectively.
16. SAND
    + identifies the normal pattern based on clustering updated through arriving batches (i.e., subsequences) and calculates each point's effective distance to the normal pattern.

**Fazit:
- Viele der Methoden sind:
	- Clustering Methoden (Sand, CBLOF)
	- Distanzbasierte Methoden mit Betrachtung der Nachbarschaft (kNN, KShapeAD,MatrixProfile, kMeansAD, MCD)
	- PCA Analysen (PCA; RobustPCA)
	- Baumbasiert (IForest, EIF)
	- Dichtebasiert (LOF,CBLOF)
- Einige verwenden:
	- Gerichtete Graphen (Series2Graph)
	- FFT (SR)
	- Histogramme (HBOS)

## Neuronale  Netze basierte Methoden
19. AutoEncoder
    + projects data to the lower-dimensional latent space and then reconstruct it through the encoding-decoding phase, where anomalies are typically characterized by evident reconstruction deviations.
20. LSTMAD
    + utilizes Long Short-Term Memory (LSTM) networks to model the relationship between current and preceding time series data, detecting anomalies through discrepancies between predicted and actual values.|
21. Donut
    + is a Variational AutoEncoder (VAE) based method and preprocesses the time series using the MCMC-based missing data imputation technique.
22. CNN
    + employ Convolutional Neural Network (CNN) to predict the next time stamp on the defined horizon and then compare the difference with the original value.
23. OmniAnomaly
    + is a stochastic recurrent neural network, which captures the normal patterns of time series by learning their robust representations with key techniques such as stochastic variable connection and planar normalizing flow, reconstructs input data by the representations, and use the reconstruction probabilities to determine anomalies.
24. USAD
    + is based on adversely trained autoencoders, and the anomaly score is the combination of discriminator and reconstruction loss.
25. AnomalyTransformer
    + utilizes the `Anomaly-Attention` mechanism to compute the association discrepancy.
26. TranAD
    + is a deep transformer network-based method, which leverages self-conditioning and adversarial training to amplify errors and gain training stability.
27. TimesNet
    + is a general time series analysis model with applications in forecasting, classification, and anomaly detection. It features TimesBlock, which can discover the multi-periodicity adaptively and extract the complex temporal variations from transformed 2D tensors by a parameter-efficient inception block.
28. FITS
    + is a lightweight model that operates on the principle that time series can be manipulated through interpolation in the complex frequency domain.

**Fazit:**
+ Autoencoder (AutoEncoder, Donut,USAD)
+ RNN (OmniAnomaly)
+ Transformer (AnomalyTransformer,TranAD)
+ CNN
+ LSTM (LSTM_AD)
+ Andere:
	+ TimesNet
	  FITS

## Foundation basierte Methoden

These models exhibit impressive few-shot or even zero-shot generalization capabilities across a broad spectrum of downstream tasks, often surpassing taskspecific models. Works in this area generally fall into two categories: the adaptation of LLMs for time-series anomaly detection tasks, and the utilization of foundation models pre-trained on large-scale time-series data for various time-series applications.

29. OFA
    + finetunes pre-trained GPT-2 model on time series data while keeping self-attention and feedforward layers of the residual blocks in the pre-trained language frozen.
30. Lag-Llama
    + is the first foundation model for univariate probabilistic time series forecasting based on a decoder-only transformer architecture that uses lags as covariates.
31. Chronos
    + tokenizes time series values using scaling and quantization into a fixed vocabulary and trains the T5 model on these tokenized time series via the cross-entropy loss.
32. TimesFM
    + is based on pretraining a decoder-style attention model with input patching, using a large time-series corpus comprising both real-world and synthetic datasets.
33. MOMENT
    + is pre-trained T5 encoder based on a masked time-series modeling approach.

# Einteilung der Methoden
## Distance-base methods [link](https://github.com/TheDatumOrg/TSB-UAD/blob/main/docs/overview/References.md#distance-base-methods)

| Method                       | Second Level     | Prototype        | Dim | Method | Stream |
| ---------------------------- | ---------------- | ---------------- | --- | ------ | ------ |
| KNN [Hawkins, 1980]          | Proximity-based  | Nearest Neighbor | M   | U      | ×      |
| LOF [Breunig et al., 2000]   | Proximity-based  | LOF              | M   | U      | ×      |
| COF [Tang et al., 2002]      | Proximity-based  | LOF              | M   | U      | ×      |
| k-Means [Hawkins, 1980]      | Clustering-based | k-Means          | M   | U      | ×      |
| MCOD [Kontaki et al., 2011]  | Clustering-based | -                | I   | U      | ×      |
| CBLOF [He et al., 2003]      | Clustering-based | LOF              | M   | U      | ×      |
| SAND [Boniol et al., 2021b]  | Clustering-based | NormA            | I   | U      | ✓      |
| NormA [Boniol et al., 2021a] | Clustering-based | NormA            | I   | U      | ×      |
## Density-based Methods [link](https://github.com/TheDatumOrg/TSB-UAD/blob/main/docs/overview/References.md#density-based-methods)

| Method                                   | Second Level       | Prototype    | Dim | Method | Stream |
| ---------------------------------------- | ------------------ | ------------ | --- | ------ | ------ |
| FAST-MCD [Rousseeuw and Driessen, 1999]  | Distribution-based | MCD          | M   | Se     | ×      |
| MC-MCD [Hardin and Rocke, 2004]          | Distribution-based | MCD          | M   | Se     | ×      |
| OCSVM [Ma and Perkins, 2003b]            | Distribution-based | SVM          | M   | Se     | ×      |
| HBOS [Goldstein and Dengel, 2013]        | Distribution-based | -            | M   | U      | ×      |
| COPOD [Li et al., 2020]                  | Distribution-based | -            | M   | U      | ×      |
| Series2Graph [Boniol and Palpanas, 2020] | Graph-based        | Series2Graph | I   | U      | ×      |
| IForest [Liu et al., 2008]               | Tree-based         | IForest      | M   | U      | ×      |
| IF-LOF [Cheng et al., 2019]              | Tree-based         | IForest/LOF  | M   | U      | ×      |
| Extended IForest [Hariri et al., 2019]   | Tree-based         | IForest      | M   | U      | ×      |
| Hybrid IForest [Marteau et al., 2017]    | Tree-based         | IForest      | M   | Se     | ×      |
| PCA [Snyder and Withers, 1983a]          | Encoding-based     | PCA          | M   | Se     | ×      |
| RobustPCA [Paffenroth et al., 2018]      | Encoding-based     | PCA          | M   | U      | ×      |
| POLY [Yao et al., 2010]                  | Encoding-based     | -            | I   | U      | ×      |

## Prediction-based Methods [link](https://github.com/TheDatumOrg/TSB-UAD/blob/main/docs/overview/References.md#prediction-based-methods)

| Method                            | Second Level         | Prototype | Dim | Method | Stream |
| --------------------------------- | -------------------- | --------- | --- | ------ | ------ |
| LSTM-AD [Malhotra et al., 2015]   | Forecasting-based    | LSTM      | M   | Se     | ×      |
| USAD [Audibert et al., 2020]      | Reconstruction-based | GAN       | M   | Se     | ×      |
| EncDec-AD [Malhotra et al., 2016] | Reconstruction-based | AE        | M   | Se     | ×      |
| DONUT [Xu et al., 2018]           | Reconstruction-based | AE        | I   | Se     | ×      |
| OmniAnomaly [Su et al., 2019]     | Reconstruction-based | AE        | M   | Se     | ×      |
